list(
  rd_family_title = list(
    lookup = "Address Lookup API: ",
    geocoding = "Geocoding: ",
    reverse = "Reverse geocoding coordinates: ",
    spatial = "Get \\code{\\link[sf:sf]{sf}} objects: ",
    api_management = "API Management: "
  )
)
